# -*- coding: utf-8 -*-
import copy
import json
import logging
from typing import Any, Dict, List, Optional

from sqlalchemy import Column, Integer, String, DateTime, func
from sqlalchemy.ext.declarative import declarative_base

from website.db.alg_model import alg_model as DB_alg_model
from website.db.enterprise_entity.enterprise_entity import EnterpriseEntityRepository
from website.db.enterprise_node import enterprise_node as DB_Node
from website.db_mysql import get_session
from website.util import shortuuid

Base = declarative_base()

class EnterpriseNodeDeviceBMCusConf(Base):
    """企业设备关联业务模型下的基础模型自定义配置"""
    __tablename__ = 'enterprise_node_device_bm_cus_conf'

    id = Column(Integer, primary_key=True, autoincrement=True)
    entity_id = Column(Integer, nullable=True)
    entity_suid = Column(String(255), nullable=True)
    node_id = Column(Integer, nullable=True)
    node_suid = Column(String(255), nullable=True)
    device_id = Column(Integer, nullable=True)
    device_suid = Column(String(255), nullable=True)
    busi_model_id = Column(Integer, nullable=True)
    busi_model_suid = Column(String(255), nullable=True)
    base_model_id = Column(Integer, nullable=True)
    base_model_suid = Column(String(255), nullable=True)
    busi_conf_file = Column(String(255), nullable=True)
    busi_conf_str = Column(String(255), nullable=True)
    model_hub_image = Column(String(255), nullable=True)
    model_conf_file = Column(String(255), nullable=True)
    model_conf_str = Column(String(255), nullable=True)
    create_time = Column(DateTime, server_default=func.now(), onupdate=func.now())

    def __repr__(self):
        return f"EnterpriseNodeDeviceBMCusConf(id={self.id}, entity_id={self.entity_id})"


class EnterpriseNodeDeviceBMCusConfRepository():

    def create_busi_model_custom_config(self, data: Dict[str, Any]):
        with get_session() as session:

            session.add(EnterpriseNodeDeviceBMCusConf(**data))
            session.commit()
        return

    def get_busi_model_custom_config(self, node_id: int, device_id: int, busi_model_id: int, base_model_id: int):
        with get_session() as session:
            data = session.query(EnterpriseNodeDeviceBMCusConf).filter(
                EnterpriseNodeDeviceBMCusConf.node_id == node_id,
                EnterpriseNodeDeviceBMCusConf.device_id == device_id,
                EnterpriseNodeDeviceBMCusConf.busi_model_id == busi_model_id,
                EnterpriseNodeDeviceBMCusConf.base_model_id == base_model_id
                ).first()
            return data